Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(106)

Unified Diff: device/bluetooth/dbus/bluetooth_gatt_descriptor_service_provider.h

Issue 1954643002: DBus support for attribute properties and permissions. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@register_and_events
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: device/bluetooth/dbus/bluetooth_gatt_descriptor_service_provider.h
diff --git a/device/bluetooth/dbus/bluetooth_gatt_descriptor_service_provider.h b/device/bluetooth/dbus/bluetooth_gatt_descriptor_service_provider.h
index 043c0138abf49c7879e872cc6b3a2131087ac364..6c5b582b0a0d2381ced36381e031c3f5de49885e 100644
--- a/device/bluetooth/dbus/bluetooth_gatt_descriptor_service_provider.h
+++ b/device/bluetooth/dbus/bluetooth_gatt_descriptor_service_provider.h
@@ -49,7 +49,7 @@ class DEVICE_BLUETOOTH_EXPORT BluetoothGattDescriptorServiceProvider {
virtual const dbus::ObjectPath& object_path() const = 0;
// Creates the instance, where |bus| is the D-Bus bus connection to export
// the object onto, |uuid| is the 128-bit GATT descriptor UUID, |permissions|
// is the list of attribute permissions, |characteristic_path| is the object
// path of the exported GATT characteristic the descriptor belongs to,
// |object_path| is the object path that the descriptor should have, and
@@ -66,7 +66,7 @@ class DEVICE_BLUETOOTH_EXPORT BluetoothGattDescriptorServiceProvider {
const dbus::ObjectPath& object_path,
std::unique_ptr<BluetoothGattAttributeValueDelegate> delegate,
const std::string& uuid,
- const std::vector<std::string>& permissions,
+ const std::vector<std::string>& flags,
const dbus::ObjectPath& characteristic_path);
protected:
@@ -49,7 +49,7 @@ class DEVICE_BLUETOOTH_EXPORT BluetoothGattDescriptorServiceProvider {
virtual const dbus::ObjectPath& object_path() const = 0;
// Creates the instance, where |bus| is the D-Bus bus connection to export
- // the object onto, |uuid| is the 128-bit GATT descriptor UUID, |permissions|
+ // the object onto, |uuid| is the 128-bit GATT descriptor UUID, |flags|
// is the list of attribute permissions, |characteristic_path| is the object
// path of the exported GATT characteristic the descriptor belongs to,

Powered by Google App Engine
This is Rietveld 408576698